@@ -1,5 +1,5 @@
 #
-# Copyright (c) 1999--2018 Red Hat, Inc.
+# Copyright (c) 1999--2017 Red Hat, Inc.
 #
 # This software is licensed to you under the GNU General Public License,
 # version 2 (GPLv2). There is NO WARRANTY for this software, express or
@@ -22,7 +22,6 @@ import os
 import sys
 from up2date_client import config
 from up2date_client import rhnserver
-from up2date_client import up2dateUtils
 
 from rhn.i18n import ustr
 
@@ -47,6 +46,12 @@ try:
 except ImportError:
     netifaces_present = False
 
+try:
+    import dmidecode
+    dmidecode_present = True
+except ImportError:
+    dmidecode_present = False
+
 import gettext
 t = gettext.translation('rhn-client-tools', fallback=True)
 # Python 3 translations don't have a ugettext method
@@ -55,9 +60,6 @@ if not hasattr(t, 'ugettext'):
 _ = t.ugettext
 
 import dbus
-with up2dateUtils.suppress_errors(['Failed to save log entry',
-                                   'SMBIOS.*: entry point at']):
-    import dmidecode
 from up2date_client import up2dateLog
 
 try:
@@ -86,7 +88,7 @@ except ImportError:
 
 # this does not change, we can cache it
 _dmi_data           = None
-_dmi_not_available  = 0
+_dmi_not_available  = 0 if dmidecode_present else 1
 
 def dmi_warnings():
     if not hasattr(dmidecode, 'get_warnings'):
@@ -94,7 +96,7 @@ def dmi_warnings():
 
     return dmidecode.get_warnings()
 
-dmi_warn = dmi_warnings()
+dmi_warn = None if _dmi_not_available else dmi_warnings()
 if dmi_warn:
     dmidecode.clear_warnings()
     log = up2dateLog.initLog()
@@ -569,10 +571,10 @@ def findHostByRoute():
             vals = info.split('=')
             if len(vals) <= 1:
                 continue
-            if vals[0].strip() == "HOSTNAME":
-                # /etc/sysconfig/network is of shell syntax,
-                # so values can be quoted
-                hostname = ''.join(vals[1:]).strip('"\' \t\n')
+            strippedstring = vals[0].strip()
+            vals[0] = strippedstring
+            if vals[0] == "HOSTNAME":
+                hostname = ''.join(vals[1:]).strip()
                 break
 
     if hostname == None or hostname == 'localhost.localdomain':
