@@ -1,6 +1,6 @@
 #
 # TUI for RHN Registration
-# Copyright (c) 2000--2020 Red Hat, Inc.
+# Copyright (c) 2000--2016 Red Hat, Inc.
 #
 # This software is licensed to you under the GNU General Public License,
 # version 2 (GPLv2). There is NO WARRANTY for this software, express or
@@ -88,7 +88,7 @@ def tui_call_wrapper(screen, func, *params):
     try:
         results = func(*params)
     except up2dateErrors.CommunicationError:
-        ErrorWindow(screen, HOSTED_CONNECTION_ERROR % config.getServerURL()[0])
+        ErrorWindow(screen, HOSTED_CONNECTION_ERROR % config.getServerlURL()[0])
         raise sys.exc_info()[1]
     except up2dateErrors.SSLCertificateVerifyFailedError:
         ErrorWindow(screen, e.errmsg)
@@ -689,6 +689,10 @@ class OSReleaseWindow:
             return msgbox
         return msgbox
 
+        if self.limited_updates_button.selected():
+            #TODO: warn
+            return msgbox
+
     def saveResults(self):
         # if limited updates save the channel and selction
         # for future use
@@ -1224,10 +1228,10 @@ class Tui:
             ReviewWindow,
             FinishWindow
             ]
-        self.serverURL = config.getServerURL()[0]
+        self.serverURL = config.getServerlURL()[0]
 
         if not cfg['sslCACert']:
-            cfg.set('sslCACert', '/usr/share/rhn/CLN-ORG-TRUSTED-SSL-CERT')
+            cfg.set('sslCACert', '/usr/share/rhn/RHN-ORG-TRUSTED-SSL-CERT')
         self.sslCACert = cfg['sslCACert']
 
     def __del__(self):
